@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package LWP::ConsoleLogger;
-$LWP::ConsoleLogger::VERSION = '0.000033';
+$LWP::ConsoleLogger::VERSION = '0.000034';
 use Data::Printer { end_separator => 1, hash_separator => ' => ' };
 use DateTime qw();
 use HTML::Restrict qw();
@@ -339,9 +339,14 @@ sub _get_content {
     return $content unless $content_type;
 
     my ( $type, $subtype ) = apply { lc $_ } parse_mime_type($content_type);
-    if (   ( $type ne 'text' )
-        && ( none { $_ eq $subtype } ( 'javascript', 'html', 'json', 'xml' ) )
-        && $subtype !~ m{$json_regex} ) {
+    if (
+        ( $type ne 'text' )
+        && (
+            none { $_ eq $subtype }
+            ( 'javascript', 'html', 'json', 'xml', 'x-www-form-urlencoded', )
+        )
+        && $subtype !~ m{$json_regex}
+        ) {
         $content = $self->_redaction_message($content_type);
     }
     elsif ( $self->content_pre_filter ) {
@@ -462,6 +467,14 @@ sub _parse_body {
             $content = substr( $content, 0, 252 ) . '...';
         }
     }
+    elsif ($type
+        && $type eq 'application'
+        && $subtype eq 'x-www-form-urlencoded' ) {
+
+        # Pretend we have query params.
+        my $uri = URI->new( '?' . $content );
+        $content = np( $uri->query_form_hash );
+    }
     elsif ( !$type || $type ne 'text' ) {
 
         # Avoid things like dumping gzipped content to the screen
@@ -520,7 +533,7 @@ LWP::ConsoleLogger - LWP tracing and debugging
 
 =head1 VERSION
 
-version 0.000033
+version 0.000034
 
 =head1 SYNOPSIS
 
@@ -855,7 +868,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by MaxMind, Inc.
+This software is Copyright (c) 2014-2017 by MaxMind, Inc.
 
 This is free software, licensed under:
 
